@@ -9,9 +9,8 @@ from contextlib import ContextDecorator
 import pathlib
 from enum import Enum
 import shutil
+import base64
 
-import copy
-import numpy as np
 import rasterio as rio
 from rasterio import warp
 from shapely.geometry import box, mapping
@@ -237,59 +236,31 @@ def get_block_info() -> dict:
     return value_dict
 
 
-def isclose(
-    transform1: rio.Affine,
-    transform2: rio.Affine,
-    rtol: float = 1e-05,
-    atol: float = 1e-08,
-) -> bool:
+def encode_str_base64(string: str) -> str:
     """
-    Operator to compare two Affine transformations. Returns true if equal under
-    tolerances.
-
-    The tolerance values are positive, typically very small numbers.
-    The relative difference (rtol * abs(b)) and the absolute difference
-    atol are added together to compare against the absolute difference
-    between a and b.
-
-    Arguments:
-        transform1: A rasterio transform object.
-        transform2: Another rasterio transform object.
-        rtol: Relative tolerance for comparison.
-        atol: Absolute tolerance for comparison.
+    A function that encodes strings in base64. The primary use case is passing complex environment variables into
+    docker containers. In cases where these env variables are complex json objects including a number of different
+    special characters the process of getting them unharmed into a docker container sometimes fails. Encoding them
+    in base64 is a save method to solve this problem.
 
+    Args:
+        A, potentially complex, non-encoded string
     Returns:
-        If the two transforms are equal within the given tolerances.
-
+        A base64-encoded string
     """
-    transform1_ar = np.array(transform1)
-    transform2_ar = np.array(transform2)
-    return np.allclose(transform1_ar, transform2_ar, rtol=rtol, atol=atol)
+    return base64.b64encode(string.encode("ascii")).decode("ascii")
 
 
-def meta_is_equal(meta1: dict, meta2: dict, rtol=1e-05, atol=1e-08) -> bool:
+def decode_str_base64(string: str) -> str:
     """
-    Operator for comparing two metadata tags provided by a rasterio dataset.
-
-    Compares affine transformations with isclose method.
-
-    Arguments:
-        meta1: A meta object.
-        meta2: Another meta object.
-        rtol: Relative tolerance for comparison.
-        atol: Absolute tolerance for comparison.
+    Inverter function for encode_str_base64
 
+    Args:
+        A base64-encoded string
     Returns:
-        If the two meta objects are equal within the given tolerances.
-
+        A decoded string
     """
-    meta1_transform = meta1.get("transform")
-    meta2_transform = meta2.get("transform")
 
-    meta1 = copy.deepcopy(meta1)
-    meta2 = copy.deepcopy(meta2)
-
-    del meta1["transform"]
-    del meta2["transform"]
-
-    return isclose(meta1_transform, meta2_transform, rtol, atol) and meta1 == meta2
+    str_encoded_byte = bytes(string, "utf-8")
+    str_decoded_byte = base64.b64decode(str_encoded_byte)
+    return str_decoded_byte.decode("utf-8")
